@@ -1,13 +1,13 @@
 from __future__ import annotations
 
 from os.path import expanduser, expandvars, isabs
-from typing import Optional
+from typing import cast
 
-from ..config.user import ConfigFile, RootConfig
-from ..project.core import Project
-from ..utils.fs import Path
-from ..utils.platform import Platform
-from .terminal import Terminal
+from hatch.cli.terminal import Terminal
+from hatch.config.user import ConfigFile, RootConfig
+from hatch.project.core import Project
+from hatch.utils.fs import Path
+from hatch.utils.platform import Platform
 
 
 class Application(Terminal):
@@ -21,11 +21,11 @@ class Application(Terminal):
         self.verbose = self.verbosity > 0
 
         # Lazily set these as we acquire more knowledge about the environment
-        self.data_dir: Optional[Path] = None
-        self.cache_dir: Optional[Path] = None
-        self.project: Optional[Project] = None
-        self.env: Optional[str] = None
-        self.env_active: Optional[str] = None
+        self.data_dir = cast(Path, None)
+        self.cache_dir = cast(Path, None)
+        self.project = cast(Project, None)
+        self.env = cast(str, None)
+        self.env_active = cast(str, None)
 
     @property
     def plugins(self):
@@ -57,6 +57,7 @@ class Application(Terminal):
             self.project.metadata,
             env_name,
             config,
+            self.project.config.matrix_variables.get(env_name, {}),
             data_dir,
             self.platform,
             self.verbosity,
@@ -86,33 +87,84 @@ class Application(Terminal):
                     with self.status_waiting('Running post-installation commands'):
                         self.run_shell_commands(environment, environment.post_install_commands, source='post-install')
 
-        if not environment.dependencies_in_sync():
+        with self.status_waiting('Checking dependencies'):
+            dependencies_in_sync = environment.dependencies_in_sync()
+
+        if not dependencies_in_sync:
             with self.status_waiting('Syncing dependencies'):
                 environment.sync_dependencies()
 
-    def run_shell_commands(self, environment, commands: list[str], source='cmd', show_code_on_error=True):
+    def run_shell_commands(
+        self, environment, commands: list[str], source='cmd', force_continue=False, show_code_on_error=True
+    ):
         with environment.command_context():
             try:
                 resolved_commands = list(environment.resolve_commands(commands))
             except Exception as e:
                 self.abort(str(e))
 
+            first_error_code = None
             should_display_command = self.verbose or len(resolved_commands) > 1
             for i, command in enumerate(resolved_commands, 1):
                 if should_display_command:
                     self.display_always(f'{source} [{i}] | {command}')
 
-                if command.startswith('-'):
-                    environment.run_shell_command(command[1:].strip())
-                    continue
+                continue_on_error = force_continue
+                if command.startswith('- '):
+                    continue_on_error = True
+                    command = command[2:]
 
                 process = environment.run_shell_command(command)
                 if process.returncode:
-                    if show_code_on_error:
+                    first_error_code = first_error_code or process.returncode
+                    if continue_on_error:
+                        continue
+                    elif show_code_on_error:
                         self.abort(f'Failed with exit code: {process.returncode}', code=process.returncode)
                     else:
                         self.abort(code=process.returncode)
 
+            if first_error_code and force_continue:
+                self.abort(code=first_error_code)
+
+    def attach_builder(self, process):
+        import pickle
+
+        with process:
+            for line in self.platform.stream_process_output(process):
+                indicator, _, procedure = line.partition(':')
+                if indicator != '__HATCH__':  # no cov
+                    self.display_info(line, end='')
+                    continue
+
+                method, args, kwargs = pickle.loads(bytes.fromhex(procedure.rstrip()))
+                if method == 'abort':
+                    process.communicate()
+
+                getattr(self, method)(*args, **kwargs)
+
+        if process.returncode:
+            self.abort(code=process.returncode)
+
+    def read_builder(self, process):
+        import pickle
+
+        lines = []
+        with process:
+            for line in self.platform.stream_process_output(process):
+                indicator, _, procedure = line.partition(':')
+                if indicator != '__HATCH__':  # no cov
+                    lines.append(line)
+                else:
+                    _, args, _ = pickle.loads(bytes.fromhex(procedure))
+                    lines.append(args[0])
+
+        output = ''.join(lines)
+        if process.returncode:
+            self.abort(output, code=process.returncode)
+
+        return output
+
     def get_env_directory(self, environment_type):
         directories = self.config.dirs.env
 
@@ -137,6 +189,7 @@ class Application(Terminal):
 class SafeApplication:
     def __init__(self, app: Application):
         self.abort = app.abort
+        self.display_always = app.display_always
         self.display_info = app.display_info
         self.display_error = app.display_error
         self.display_success = app.display_success
@@ -146,4 +199,6 @@ class SafeApplication:
         self.display_mini_header = app.display_mini_header
         # Divergence from what the backend provides
         self.prompt = app.prompt
+        self.confirm = app.confirm
         self.status_waiting = app.status_waiting
+        self.read_builder = app.read_builder
